@@ -89,7 +89,6 @@ eel_gconf_handle_error (GError **error)
 			eel_show_error_dialog (message, 
 			                       _("All further errors shown "
 			                       "only on terminal."),
-					       _("GConf Error"), 
 			                       NULL);
 			g_free (message);
 		}
@@ -318,7 +317,7 @@ eel_gconf_monitor_add (const char *directory)
 
 	g_return_val_if_fail (directory != NULL, FALSE);
 
-	client = gconf_client_get_default ();
+	client = eel_gconf_client_get_global ();
 	g_return_val_if_fail (client != NULL, FALSE);
 
 	gconf_client_add_dir (client,
@@ -343,7 +342,7 @@ eel_gconf_monitor_remove (const char *directory)
 		return FALSE;
 	}
 
-	client = gconf_client_get_default ();
+	client = eel_gconf_client_get_global ();
 	g_return_val_if_fail (client != NULL, FALSE);
 	
 	gconf_client_remove_dir (client,
@@ -368,7 +367,7 @@ eel_gconf_preload_cache (const char             *directory,
 		return;
 	}
 
-	client = gconf_client_get_default ();
+	client = eel_gconf_client_get_global ();
 	g_return_if_fail (client != NULL);
 	
 	gconf_client_preload (client,
@@ -615,9 +614,9 @@ eel_gconf_value_get_string_list (const GConfValue *value)
 		g_return_val_if_fail (next_value != NULL, NULL);
 		g_return_val_if_fail (next_value->type == GCONF_VALUE_STRING, NULL);
 		string = gconf_value_get_string (next_value);
-		result = g_slist_append (result, g_strdup (string));
+		result = g_slist_prepend (result, g_strdup (string));
 	}
-	return result;
+	return g_slist_reverse (result);
 }
 
 void
@@ -646,20 +645,3 @@ eel_gconf_value_set_string_list (GConfValue *value,
 	g_slist_free (value_list);
 }
 
-EelStringList *
-eel_gconf_value_get_eel_string_list (const GConfValue *value)
-{
-	GSList *slist;
-	EelStringList *result;
-
-	if (value == NULL) {
-		return eel_string_list_new (TRUE);
-	}
-	g_return_val_if_fail (value->type == GCONF_VALUE_LIST, eel_string_list_new (TRUE));
-	g_return_val_if_fail (gconf_value_get_list_type (value) == GCONF_VALUE_STRING, eel_string_list_new (TRUE));
-
-	slist = eel_gconf_value_get_string_list (value);
-	result = eel_string_list_new_from_g_slist (slist, TRUE);
-	eel_g_slist_free_deep (slist);
- 	return result;
-}
